@@ -1,3 +1,19 @@
+'''
+    This file is part of PM4Py (More Info: https://pm4py.fit.fraunhofer.de).
+
+    PM4Py is free software: you can redistribute it and/or modify
+    it under the terms of the GNU General Public License as published by
+    the Free Software Foundation, either version 3 of the License, or
+    (at your option) any later version.
+
+    PM4Py is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+    GNU General Public License for more details.
+
+    You should have received a copy of the GNU General Public License
+    along with PM4Py.  If not, see <https://www.gnu.org/licenses/>.
+'''
 from pm4py.algo.conformance.alignments.variants.dijkstra_less_memory import __add_to_open_set, __add_closed, \
     __check_closed, __decode_marking, __encode_marking, __fire_trans, __dict_leq, \
     __transform_model_to_mem_efficient_structure, __transform_trace_to_mem_efficient_structure, __reconstruct_alignment, \
@@ -484,6 +500,9 @@ def __align(model_struct, trace_struct, product_net, corresp, sync_cost=align_ut
         trustable = curr[POSITION_TRUSTABLE]
 
         if not trustable:
+            if (time.time() - start_time) > max_align_time_trace:
+                return None
+            
             m, t = get_corresp_marking_and_trans(curr_m, index, corresp, None)
             h, x = utils.__compute_exact_heuristic_new_version(sync_net, a_matrix, h_cvx, g_matrix, cost_vec,
                                                                incidence_matrix, m, fin_vec,
