@@ -1,3 +1,19 @@
+'''
+    This file is part of PM4Py (More Info: https://pm4py.fit.fraunhofer.de).
+
+    PM4Py is free software: you can redistribute it and/or modify
+    it under the terms of the GNU General Public License as published by
+    the Free Software Foundation, either version 3 of the License, or
+    (at your option) any later version.
+
+    PM4Py is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+    GNU General Public License for more details.
+
+    You should have received a copy of the GNU General Public License
+    along with PM4Py.  If not, see <https://www.gnu.org/licenses/>.
+'''
 import numpy as np
 from pm4py.util.lp import solver as lp_solver
 from pm4py.objects.petri.petrinet import Marking
@@ -108,7 +124,7 @@ def __get_alt(open_set, new_marking):
             return item
 
 
-def __reconstruct_alignment(state, visited, queued, traversed, ret_tuple_as_trans_desc=False):
+def __reconstruct_alignment(state, visited, queued, traversed, ret_tuple_as_trans_desc=False, lp_solved = 0):
     parent = state.p
     if ret_tuple_as_trans_desc:
         alignment = [(state.t.name, state.t.label)]
@@ -121,7 +137,7 @@ def __reconstruct_alignment(state, visited, queued, traversed, ret_tuple_as_tran
             alignment = [parent.t.label] + alignment
             parent = parent.p
     return {'alignment': alignment, 'cost': state.g, 'visited_states': visited, 'queued_states': queued,
-            'traversed_arcs': traversed}
+            'traversed_arcs': traversed, 'lp_solved': lp_solved}
 
 
 def __derive_heuristic(incidence_matrix, cost_vec, x, t, h):
